==> owncloud-10.0.7.tgz: owncloud/core/l10n/hy.js <==
OC.L10N.register(
    "core",
    {
    "File is too big" : "Ֆայլը չափազանց մեծ է",
    "Unknown filetype" : "Անհայտ ֆայլի տիպ",
    "Invalid image" : "Անվավեր նկար",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Updated \"%s\" to %s" : "«%s» թարմացրեցի %sն",
    "Sunday" : "Կիրակի",
    "Monday" : "Երկուշաբթի",
    "Tuesday" : "Երեքշաբթի",
    "Wednesday" : "Չորեքշաբթի",
    "Thursday" : "Հինգշաբթի",
    "Friday" : "Ուրբաթ",
    "Saturday" : "Շաբաթ",
    "Sun." : "Կիր.",
    "Mon." : "Երկ.",
    "Tue." : "Երք.",
    "Wed." : "Չոր.",
    "Thu." : "Հնգ.",
    "Fri." : "Ուրբ.",
    "Sat." : "Շաբ.",
    "Su" : "Կիր",
    "Mo" : "Երկ",
    "Tu" : "Երք",
    "We" : "Չոր",
    "Th" : "Հնգ",
    "Fr" : "Ուրբ",
    "Sa" : "Շաբ",
    "January" : "Հունվար",
    "February" : "Փետրվար",
    "March" : "Մարտ",
    "April" : "Ապրիլ",
    "May" : "Մայիս",
    "June" : "Հունիս",
    "July" : "Հուլիս",
    "August" : "Օգոստոս",
    "September" : "Սեպտեմբեր",
    "October" : "Հոկտեմբեր",
    "November" : "Նոյեմբեր",
    "December" : "Դեկտեմբեր",
    "Jan." : "Հնվ.",
    "Feb." : "Փտվ.",
    "Mar." : "Մրտ.",
    "Apr." : "Ապր.",
    "May." : "Մյս.",
    "Jun." : "Հնս.",
    "Jul." : "Հլս.",
    "Aug." : "Օգս.",
    "Sep." : "Սեպ.",
    "Oct." : "Հոկ.",
    "Nov." : "Նոյ.",
    "Dec." : "Դեկ.",
    "Settings" : "Կարգավորումներ",
    "Saving..." : "Պահում եմ...",
    "seconds ago" : "վրկ. առաջ",
    "No" : "Ոչ",
    "Yes" : "Այո",
    "Choose" : "Ընտրել",
    "Ok" : "Լավ",
    "One file conflict" : "Մի ֆայլի հակասություն",
    "New Files" : "Նոր ֆայլեր",
    "Already existing files" : "Արդեն առկա ֆայլեր",
    "Which files do you want to keep?" : "Ո՞ր ֆայլերն ես ցանկանում պահպանել",
    "Cancel" : "Չեղարկել",
    "Continue" : "Շարունակել",
    "(all selected)" : "(բոլորն են ընտրված)",
    "({count} selected)" : "({count} ընտրված)",
    "Very weak password" : "Շատ թույլ գաղտնաբառ",
    "Weak password" : "Թույլ գաղտնաբառ",
    "So-so password" : "Միջինոտ գաղտնաբառ",
    "Good password" : "Լավ գաղտնաբառ",
    "Strong password" : "Ուժեղ գաղտնաբառ",
    "Shared" : "Կիսված",
    "Shared with {recipients}" : "{recipients}ի հետ կիսված",
    "Error" : "Սխալ",
    "Error while sharing" : "Սխալ տարածելիս",
    "Set expiration date" : "Սահմանել վավերականության ժամկետ",
    "Expiration" : "Վավ. ժամկետ",
    "Expiration date" : "Վավերականության ժամկետ",
    "Link" : "Հղում",
    "Edit" : "Խմբագրել",
    "Remove" : "Ջնջել",
    "Password" : "Գաղտնաբառ",
    "Name" : "Անուն",
    "Allow editing" : "Թույլատրել խմբագրումը",
    "Save" : "Պահել",
    "Email sent" : "Էլ. նամակը ուղարկվեց",
    "Email link to person" : "Ուղարկել հղումը ոմնին",
    "group" : "խումբ",
    "remote" : "հեռակա",
    "Unshare" : "Չկիսվել",
    "can share" : "կարող է տարածել",
    "can edit" : "կարող է խմբագրել",
    "create" : "ստեղծել",
    "change" : "փոխել",
    "delete" : "ջնջել",
    "Share" : "Կիսվել",
    "Warning" : "Զգուշացում",
    "Non-existing tag #{tag}" : "Գոյություն չունեցող պիտակ #{tag}",
    "restricted" : "սահմանափակ",
    "invisible" : "անտեսանելի",
    "({scope})" : "({scope})",
    "Delete" : "Ջնջել",
    "Rename" : "Վերանվանել",
    "Enter new" : "Նորը ավելացնել",
    "Add" : "Ավելացնել",
    "Edit tags" : "Խմբագրել պիտակները",
    "No tags selected for deletion." : "Ջնջելու համար պիտակներ նշված չեն",
    "unknown text" : "անհայտ տեքստ",
    "Hello world!" : "Բա՛րև աշխարհ։",
    "sunny" : "արևոտ",
    "Hello {name}, the weather is {weather}" : "Բարև {name}, եղանակը {weather} է",
    "Hello {name}" : "Բարև {name}",
    "new" : "նոր",
    "_download %n file_::_download %n files_" : ["ներբեռնել %n ֆայլ","ներբեռնել %n ֆայլ"],
    "Personal" : "Անձնական",
    "Users" : "Օգտատերեր",
    "Apps" : "Ափփեր",
    "Admin" : "Ադմին",
    "Help" : "Օգնություն",
    "File not found" : "Ֆայլը չգտնվեց",
    "Cheers!" : "Չը՛խկ",
    "Type: %s" : "Տիպ. %s",
    "Code: %s" : "Կոդ. %s",
    "Message: %s" : "Նամակ. %s",
    "File: %s" : "Ֆայլ. %s",
    "Line: %s" : "Տող. %s",
    "Trace" : "Հետք",
    "Username" : "Օգտանուն",
    "Data folder" : "Տվյալների պանակ",
    "Only %s is available." : "Միայն %sն է հասանելի։",
    "Need help?" : "Օգնությո՞ւն",
    "Log out" : "Դուրս գալ",
    "Search" : "Փնտրել",
    "Username or email" : "Օգտանուն կամ էլ. հասցե",
    "Log in" : "Մուտք գործել",
    "Wrong password." : "Սխալ գաղտնաբառ։",
    "Stay logged in" : "Մնալ մուտք գործած",
    "Alternative Logins" : "Այլընտրանքային մուտքեր",
    "New password" : "Նոր գաղտնաբառ",
    "New Password" : "Նոր գաղտնաբառ",
    "Two-step verification" : "Երկաստիճան ստուգում",
    "Cancel login" : "Չեղարկել մուտք գործումը",
    "App update required" : "Հարկավոր է ափփի թարմացում",
    "Start update" : "Սկսել թարմացումը",
    "Update needed" : "Թարմացում է հարկավոր"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/core/l10n/hy.js <==
OC.L10N.register(
    "core",
    {
    "File is too big" : "Ֆայլը չափազանց մեծ է",
    "Unknown filetype" : "Անհայտ ֆայլի տիպ",
    "Invalid image" : "Անվավեր նկար",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Updated \"%s\" to %s" : "«%s» թարմացրեցի %sն",
    "Sunday" : "Կիրակի",
    "Monday" : "Երկուշաբթի",
    "Tuesday" : "Երեքշաբթի",
    "Wednesday" : "Չորեքշաբթի",
    "Thursday" : "Հինգշաբթի",
    "Friday" : "Ուրբաթ",
    "Saturday" : "Շաբաթ",
    "Sun." : "Կիր.",
    "Mon." : "Երկ.",
    "Tue." : "Երք.",
    "Wed." : "Չոր.",
    "Thu." : "Հնգ.",
    "Fri." : "Ուրբ.",
    "Sat." : "Շաբ.",
    "Su" : "Կիր",
    "Mo" : "Երկ",
    "Tu" : "Երք",
    "We" : "Չոր",
    "Th" : "Հնգ",
    "Fr" : "Ուրբ",
    "Sa" : "Շաբ",
    "January" : "Հունվար",
    "February" : "Փետրվար",
    "March" : "Մարտ",
    "April" : "Ապրիլ",
    "May" : "Մայիս",
    "June" : "Հունիս",
    "July" : "Հուլիս",
    "August" : "Օգոստոս",
    "September" : "Սեպտեմբեր",
    "October" : "Հոկտեմբեր",
    "November" : "Նոյեմբեր",
    "December" : "Դեկտեմբեր",
    "Jan." : "Հնվ.",
    "Feb." : "Փտվ.",
    "Mar." : "Մրտ.",
    "Apr." : "Ապր.",
    "May." : "Մյս.",
    "Jun." : "Հնս.",
    "Jul." : "Հլս.",
    "Aug." : "Օգս.",
    "Sep." : "Սեպ.",
    "Oct." : "Հոկ.",
    "Nov." : "Նոյ.",
    "Dec." : "Դեկ.",
    "Settings" : "Կարգավորումներ",
    "Saving..." : "Պահում եմ...",
    "seconds ago" : "վրկ. առաջ",
    "No" : "Ոչ",
    "Yes" : "Այո",
    "Choose" : "Ընտրել",
    "Ok" : "Լավ",
    "One file conflict" : "Մի ֆայլի հակասություն",
    "New Files" : "Նոր ֆայլեր",
    "Already existing files" : "Արդեն առկա ֆայլեր",
    "Which files do you want to keep?" : "Ո՞ր ֆայլերն ես ցանկանում պահպանել",
    "Cancel" : "Չեղարկել",
    "Continue" : "Շարունակել",
    "(all selected)" : "(բոլորն են ընտրված)",
    "({count} selected)" : "({count} ընտրված)",
    "Very weak password" : "Շատ թույլ գաղտնաբառ",
    "Weak password" : "Թույլ գաղտնաբառ",
    "So-so password" : "Միջինոտ գաղտնաբառ",
    "Good password" : "Լավ գաղտնաբառ",
    "Strong password" : "Ուժեղ գաղտնաբառ",
    "Shared" : "Կիսված",
    "Shared with {recipients}" : "{recipients}ի հետ կիսված",
    "Error" : "Սխալ",
    "Error while sharing" : "Սխալ տարածելիս",
    "Set expiration date" : "Սահմանել վավերականության ժամկետ",
    "Expiration" : "Վավ. ժամկետ",
    "Expiration date" : "Վավերականության ժամկետ",
    "Link" : "Հղում",
    "Edit" : "Խմբագրել",
    "Remove" : "Ջնջել",
    "Password" : "Գաղտնաբառ",
    "Name" : "Անուն",
    "Allow editing" : "Թույլատրել խմբագրումը",
    "Save" : "Պահել",
    "Email sent" : "Էլ. նամակը ուղարկվեց",
    "Email link to person" : "Ուղարկել հղումը ոմնին",
    "group" : "խումբ",
    "remote" : "հեռակա",
    "Unshare" : "Չկիսվել",
    "can share" : "կարող է տարածել",
    "can edit" : "կարող է խմբագրել",
    "create" : "ստեղծել",
    "change" : "փոխել",
    "delete" : "ջնջել",
    "Share" : "Կիսվել",
    "Warning" : "Զգուշացում",
    "Non-existing tag #{tag}" : "Գոյություն չունեցող պիտակ #{tag}",
    "restricted" : "սահմանափակ",
    "invisible" : "անտեսանելի",
    "({scope})" : "({scope})",
    "Delete" : "Ջնջել",
    "Rename" : "Վերանվանել",
    "Enter new" : "Նորը ավելացնել",
    "Add" : "Ավելացնել",
    "Edit tags" : "Խմբագրել պիտակները",
    "No tags selected for deletion." : "Ջնջելու համար պիտակներ նշված չեն",
    "unknown text" : "անհայտ տեքստ",
    "Hello world!" : "Բա՛րև աշխարհ։",
    "sunny" : "արևոտ",
    "Hello {name}, the weather is {weather}" : "Բարև {name}, եղանակը {weather} է",
    "Hello {name}" : "Բարև {name}",
    "new" : "նոր",
    "_download %n file_::_download %n files_" : ["ներբեռնել %n ֆայլ","ներբեռնել %n ֆայլ"],
    "Personal" : "Անձնական",
    "Users" : "Օգտատերեր",
    "Apps" : "Ափփեր",
    "Admin" : "Ադմին",
    "Help" : "Օգնություն",
    "File not found" : "Ֆայլը չգտնվեց",
    "Cheers!" : "Չը՛խկ",
    "Type: %s" : "Տիպ. %s",
    "Code: %s" : "Կոդ. %s",
    "Message: %s" : "Նամակ. %s",
    "File: %s" : "Ֆայլ. %s",
    "Line: %s" : "Տող. %s",
    "Trace" : "Հետք",
    "Username" : "Օգտանուն",
    "Data folder" : "Տվյալների պանակ",
    "Only %s is available." : "Միայն %sն է հասանելի։",
    "Need help?" : "Օգնությո՞ւն",
    "Log out" : "Դուրս գալ",
    "Search" : "Փնտրել",
    "Username or email" : "Օգտանուն կամ էլ. հասցե",
    "Log in" : "Մուտք գործել",
    "Wrong password." : "Սխալ գաղտնաբառ։",
    "Stay logged in" : "Մնալ մուտք գործած",
    "Alternative Logins" : "Այլընտրանքային մուտքեր",
    "New password" : "Նոր գաղտնաբառ",
    "New Password" : "Նոր գաղտնաբառ",
    "Two-step verification" : "Երկաստիճան ստուգում",
    "Cancel login" : "Չեղարկել մուտք գործումը",
    "App update required" : "Հարկավոր է ափփի թարմացում",
    "Start update" : "Սկսել թարմացումը",
    "Update needed" : "Թարմացում է հարկավոր",
    "Technical details" : "Տեխնիկական մանրամասներ",
    "Remote Address: %s" : "Հեռակա հասցե. %s"
},
"nplurals=2; plural=(n != 1);");
